module.exports = {
  /**
   * 결제 대기 중
   * 결제 건이 생성되었고, 구매자의 결제 진행을 대기 중인 상태.
   * 이 상태에서 구매자나 가맹점이 결제를 취소할 수 있습니다.
   * 또한 설정한 '만료 기간'이 도래하면 자동으로 취소됩니다.
   */
  PAY_STANDBY: 'PAY_STANDBY',
  /**
   * 구매자 인증 완료 (수동 승인 설정시)
   * 결제를 위한 구매자 인증 완료되고, 가맹점의 최종 승인을 기다리는 상태.
   * (결제 생성 시 'autoExecute'를 false로 설정한 경우에만 이 단계를 거칩니다)
   */
  PAY_APPROVED: 'PAY_APPROVED',
  /**
   * 결제 취소
   * 결제가 완료되기 전에 구매자나 가맹점이 결제를 취소한 상태입니다. (결론적으론 금액의 이동 없이 종료된 건)
   */
  PAY_CANCEL: 'PAY_CANCEL',
  /**
   * 결제 진행 중
   * 구매자가 결제를 승인하여 구매자의 계좌에서 결제 금액을 출금 처리 중인 상태입니다.
   */
  PAY_PROGRESS: 'PAY_PROGRESS',
  /**
   * 결제 완료
   * 구매자 및 가맹점의 결제 승인 및 출금이 정상적으로 완료된 상태입니다.
   * 에스크로 결제 건의 경우, 자동으로 '배송등록 대기 중' 상태로 변경됩니다.
   */
  PAY_COMPLETE: 'PAY_COMPLETE',
  /**
   * 환불 진행중
   * 전액 또는 부분 환불을 진행 중인 상태로, 완료되기 전 까지 다른 환불을 진행할 수 없습니다.
   */
  REFUND_PROGRESS: 'REFUND_PROGRESS',
  /**
   * 환불 성공
   * 전액 또는 부분 환불이 완료되어, 환불 처리한 금액이 구매자의 계좌로 입금 완료된 상태입니다.
   */
  REFUND_SUCCESS: 'REFUND_SUCCESS',
  /**
   * 정산 완료
   * 결제 완료된 금액에 대해 정산이 완료되어 더 이상 환불이 불가한 상태입니다.
   * (승인일 또는 구매 확정일로부터 180일 경과)
   */
  SETTLEMENT_COMPLETE: 'SETTLEMENT_COMPLETE',
  /**
   * 환불 정산 완료
   * 전액 또는 부분 환불에 대한 정산이 완료되어 더 이상 환불이 불가한 상태입니다.
   * (승인일 또는 구매 확정일로부터 180일 경과했거나 전액 환불에 대한 정산 완료된 경우)
   */
  SETTLEMENT_REFUND_COMPLETE: 'SETTLEMENT_REFUND_COMPLETE',
  /**
   * 배송등록 대기중 (에스크로 요청)
   * 에스크로 결제 건이 결제 완료된 후, 매매보호에 들어간 상태입니다.
   * 판매자가 '배송 등록'을 하면 '구매확정 대기 중' 상태로 변경되며,
   * 120일 동안 배송 등록을 하지 않는 경우에도 자동으로 '구매확정 대기 중' 상태로 변경됩니다.
   */
  ESCROW_REQUEST: 'ESCROW_REQUEST',
  /**
   * 구매확정 대기중 (에스크로 해제)
   * 판매자가 '배송 등록'을 완료하고 구매자의 '구매 확정'을 대기 중인 상태입니다.
   * 구매자가 구매 확정을 하면 판매자 대금 지급 과정을 시작하고,
   * 구매자가 지급을 거부하면 '구매자 지급 거부' 상태로 변경됩니다.
   */
  ESCROW_RELEASE: 'ESCROW_RELEASE',
  /**
   * 구매자 지급 거부 (에스크로 거부)
   * 구매자가 지급을 거절한 상태입니다.
   * 판매자는 이 건을 전액 환불 처리하거나 구매자에게 '구매 확정'을 다시 요청할 수 있습니다.
   */
  ESCROW_DENY: 'ESCROW_DENY'
}
